﻿Imports System.Text
Imports System.Threading.Tasks

Imports Microsoft.Azure ' Namespace for CloudConfigurationManager
Imports Microsoft.WindowsAzure.Storage ' Namespace for CloudStorageAccount
Imports Microsoft.WindowsAzure.Storage.Auth ' Namespace for authentication types
Imports Microsoft.WindowsAzure.Storage.Blob ' Namespace for Blob storage types

Imports System.Console 'new C# 6 feature

Namespace UploadToBlob
	Friend Class Program
		Shared Sub Main(ByVal args() As String)
			Try
				WriteLine("Start upload to Azure Storage Container")
				' Retrieve storage account from connection string.
				'be sure to update the StorageConnectionString in the App.config with your storage account and access key
				Dim storageAccount As CloudStorageAccount = CloudStorageAccount.Parse(CloudConfigurationManager.GetSetting("StorageConnectionString"))

				' Create the blob client.
				Dim blobClient As CloudBlobClient = storageAccount.CreateCloudBlobClient()

				' Retrieve reference to a previously created container.
				Dim container As CloudBlobContainer = blobClient.GetContainerReference("pdf")

                'if the container does not exist, create it
                If container.CreateIfNotExists Then
                    WriteLine($"Created container '{container.Name}' " & $"in storage account '{storageAccount.Credentials.AccountName}'.")
                Else
                    WriteLine($"Container '{container.Name}' already exists " & $"for storage account '{storageAccount.Credentials.AccountName}'.")
				End If

				'Containers are private by default, set to public and accessible to everyone
				container.SetPermissions(New BlobContainerPermissions With {.PublicAccess = BlobContainerPublicAccessType.Blob})
				WriteLine($"Permission for container '{container.Name}' is public.")

				' Retrieve reference to a blob named "myblob".
				Dim blockBlob As CloudBlockBlob = container.GetBlockBlobReference("htmlSite.pdf")

				' Create or overwrite the "myblob" blob with contents from a local file.
				Using fileStream = System.IO.File.OpenRead("htmlSite.pdf")
					blockBlob.UploadFromStream(fileStream)
				End Using
				WriteLine($"Uploaded PDF to '{storageAccount.Credentials.AccountName}/pdf' successfully.")

'				#Region "List blobs in container"
				' List the blob card images in a container 
				' Loop over items within the container and output the length and URI.
				Dim numberOfFiles As Integer = 0
				For Each item As IListBlobItem In container.ListBlobs(Nothing, False)
                    If CType(item, Object).GetType Is GetType(CloudBlockBlob) Then
                        Dim blob As CloudBlockBlob = CType(item, CloudBlockBlob)
                        WriteLine($"PDF url '{blob.Uri}' with length of {blob.Properties.Length}")
                    End If
                    numberOfFiles += 1
				Next item
                WriteLine($"Listed {numberOfFiles.ToString} PDF(s).")
                '				#End Region
                '				#Region "Delete Blobs"
                ' Retrieve reference to a blob and delete it
                WriteLine("Enter Y to delete listed cards, press enter to skip deletion:")
				If ReadLine() = "Y" Then
					numberOfFiles = 0
					For Each item As IListBlobItem In container.ListBlobs(Nothing, False)
						Dim blob As CloudBlockBlob = CType(item, CloudBlockBlob)
						Dim blockBlobToDelete As CloudBlockBlob = container.GetBlockBlobReference(blob.Name)
						blockBlobToDelete.Delete()
						WriteLine($"Deleted: '{blob.Name}' which was {blob.Name.Length} bytes.")
						numberOfFiles += 1
					Next item
                    WriteLine($"Deleted {numberOfFiles.ToString} PDFs.")
                End If
'				#End Region
			Catch ex As StorageException
				WriteLine($"StorageException: {ex.Message}")
			Catch ex As Exception
				WriteLine($"Exception: {ex.Message}")
			End Try

			WriteLine("Press enter to exit.")
			ReadLine()

		End Sub
	End Class
End Namespace
