﻿Imports System.Text
Imports System.Threading.Tasks

Imports Microsoft.Azure ' Namespace for CloudConfigurationManager
Imports Microsoft.WindowsAzure.Storage ' Namespace for CloudStorageAccount
Imports Microsoft.WindowsAzure.Storage.Auth ' Namespace for authentication types
Imports Microsoft.WindowsAzure.Storage.Blob ' Namespace for Blob storage types

Imports System.Console

Namespace convertToPDF
	Friend Class Program
		Shared Sub Main(ByVal args() As String)
			Dim URL = args(0)
			Dim filename = args(1)
'			#Region "convert to PDF"
			Try
                WriteLine($"Convert: {URL} to {filename} at {DateTime.Now.ToString}") 'cool string interpolation new in C# 6
                Using p = New Process
                    Dim startInfo = New ProcessStartInfo With {.FileName = "wkhtmltopdf.exe", .Arguments = URL & " " & filename, .UseShellExecute = False, .RedirectStandardOutput = True, .RedirectStandardError = True, .RedirectStandardInput = True}
                    p.StartInfo = startInfo
                    WriteLine($"Conversion started: {DateTime.Now.ToString}")
                    p.Start()
                    WriteLine($"Process started: {DateTime.Now.ToString}")
                    p.WaitForExit()
                    WriteLine($"Conversion completed: {DateTime.Now.ToString}")
                    Dim exitCode = p.ExitCode
                    p.Close()
                End Using
            Catch ex As Exception
				WriteLine($"Something Happened: {ex.Message}")
				'add some code here to not attempt to upload if the PDF creation failed
				'return a failure to the API and diaply to the client
			End Try
            WriteLine($"Conversion successful: {DateTime.Now.ToString}")
            '			#End Region
            '			#Region "Upload to Azure Storage Container"
            Try
				WriteLine("Start upload to Azure Storage Container")
				' Retrieve storage account from connection string.
				'be sure to update the StorageConnectionString in the App.config with your storage account and access key
				Dim storageAccount As CloudStorageAccount = CloudStorageAccount.Parse(CloudConfigurationManager.GetSetting("StorageConnectionString"))

                ' Create the blob client.
                Dim blobClient As CloudBlobClient = storageAccount.CreateCloudBlobClient

                ' Retrieve reference to a previously created container.
                Dim container As CloudBlobContainer = blobClient.GetContainerReference("pdf")

                'if the container does not exist, create it
                If container.CreateIfNotExists Then
                    WriteLine($"Created container '{container.Name}' " & $"in storage account '{storageAccount.Credentials.AccountName}'.")

                    'Containers are private by default, set to public and accessible to everyone
                    container.SetPermissions(New BlobContainerPermissions With {.PublicAccess = BlobContainerPublicAccessType.Blob})
                Else
                    WriteLine($"Container '{container.Name}' already exists " & $"for storage account '{storageAccount.Credentials.AccountName}'.")
				End If

				WriteLine($"Permission for container '{container.Name}' is public.")

				' Retrieve reference to a blob named "pdf".
				Dim blockBlob As CloudBlockBlob = container.GetBlockBlobReference(filename)

				' Create or overwrite the "pdf" blob with contents from a local file.
				Using fileStream = System.IO.File.OpenRead(filename)
					blockBlob.UploadFromStream(fileStream)
				End Using
				WriteLine($"Uploaded PDF to '{storageAccount.Credentials.AccountName}/pdf' successfully.")
			Catch ex As StorageException
				WriteLine($"StorageException: {ex.Message}")
			Catch ex As Exception
				WriteLine($"Exception: {ex.Message}")
			End Try
'			#End Region
		End Sub
	End Class
End Namespace
